@@ -95,7 +95,7 @@ void a_param_out_str(FILE *stream, a_param_ptr p)
     param_out_int(stream, "sign0", p->sign0);
 }
 
-void a_param_inp_generic (a_param_ptr p, fetch_ops_t *fops, void *ctx)
+void a_param_inp_generic (a_param_ptr p, fetch_ops_t fops, void *ctx)
 {
     assert (fops);
     assert (ctx);
@@ -116,20 +116,6 @@ void a_param_inp_generic (a_param_ptr p, fetch_ops_t *fops, void *ctx)
     symtab_clear(tab);
 }
 
-void a_param_inp_buf (a_param_ptr p, const char *buf, size_t len) 
-{
-    assert (buf);
-    tracker_t t;
-    tracker_init (&t, buf, len);
-    a_param_inp_generic (p, &fops_buf, &t);
-}
-
-void a_param_inp_str (a_param_ptr p, FILE *stream)
-{
-    assert (stream);
-    a_param_inp_generic (p, &fops_str, stream);
-}
-
 static void phi_identity(element_ptr out, element_ptr in, pairing_ptr pairing)
 {
     (void) pairing;
