@@ -21,12 +21,22 @@ struct d_param_s {
 typedef struct d_param_s d_param_t[1];
 typedef struct d_param_s *d_param_ptr;
 
-void d_param_init(d_param_ptr cc);
-void d_param_clear(d_param_ptr cc);
+/*@manual dparam
+Initialize ''p''. This must be called before ''p'' can be used.
+*/
+void d_param_init(d_param_ptr p);
+
+/*@manual dparam
+Clear ''p''. This should be called after ''p'' is no longer needed.
+*/
+void d_param_clear(d_param_ptr p);
+
+/*@manual dparam
+Write the parameters in ''p'' in a text format onto ''stream''.
+*/
 void d_param_out_str(FILE *stream, d_param_ptr p);
-void d_param_inp_generic (d_param_ptr p, fetch_ops_t *fops, void *ctx);
-void d_param_inp_buf (d_param_ptr p, const char *buf, size_t len);
-void d_param_inp_str(d_param_ptr p, FILE *stream);
+
+void d_param_inp_generic (d_param_ptr p, fetch_ops_t fops, void *ctx);
 void pairing_init_c_param(pairing_t pairing, d_param_t param);
 
 static inline void d_param_init_inp_str(d_param_ptr p, FILE *stream)
@@ -35,5 +45,14 @@ static inline void d_param_init_inp_str(d_param_ptr p, FILE *stream)
     d_param_init_inp_str(p, stream);
 }
 
-void d_param_from_cm(d_param_t param, cm_info_ptr cm);
+/*@manual dparam
+Type D curves are generated using the
+complex multiplication (CM) method.
+This function sets ''p'' to
+a type D pairing parameters from CM parameters ''cm''.
+Another part of the library searches for
+appropriate CM parameters (see below)
+and the results can be passed to this function
+*/
+void d_param_from_cm(d_param_t p, cm_info_ptr cm);
 #endif //C_PARAM_H
