@@ -24,6 +24,6 @@ void token_init(token_t tok);
 void token_clear(token_t tok);
 void token_get(token_t tok, FILE *stream);
 void token_get_from_buf (token_t tok, const char *buf, char **p, size_t len);
-void token_get_generic (token_t tok, fetch_ops_t *fops, void *ctx);
+void token_get_generic (token_t tok, fetch_ops_t fops, void *ctx);
 
 #endif //PARSE_H
